Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3321)

Unified Diff: base/win_util.h

Issue 3165064: Move the keyboard files from base/ to app/. (Closed) Base URL: http://src.chromium.org/git/chromium.git
Patch Set: latest merge Created 10 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « base/keyboard_code_conversion_unittest.cc ('k') | base/win_util.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: base/win_util.h
diff --git a/base/win_util.h b/base/win_util.h
index 3a3373297c3bbb60e401438446d99a0e24d504b3..c2ebcd70e1014472727e85449fb0178c7dac1f59 100644
--- a/base/win_util.h
+++ b/base/win_util.h
@@ -12,7 +12,7 @@
#include <string>
-#include "base/keyboard_codes.h"
+#include "app/keyboard_codes.h"
namespace win_util {
@@ -113,9 +113,9 @@ std::wstring FormatMessage(unsigned messageid);
// Uses the last Win32 error to generate a human readable message string.
std::wstring FormatLastWin32Error();
-// Methods to convert base::KeyboardCode/Windows virtual key type methods.
-WORD KeyboardCodeToWin(base::KeyboardCode keycode);
-base::KeyboardCode WinToKeyboardCode(WORD keycode);
+// Methods to convert app::KeyboardCode/Windows virtual key type methods.
+WORD KeyboardCodeToWin(app::KeyboardCode keycode);
+app::KeyboardCode WinToKeyboardCode(WORD keycode);
// Sets the application id in given IPropertyStore. The function is intended
// for tagging application/chromium shortcut, browser window and jump list for
« no previous file with comments | « base/keyboard_code_conversion_unittest.cc ('k') | base/win_util.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698